package micro

import (
	"context"
	"git.nspix.com/golang/micro/registry"
)

type (
	Options struct {
		Zone       string `json:"zone"`
		Name       string `json:"name"`
		Version    string `json:"version"`
		EnableHttp bool   `json:"enable_http"`
		EnableRPC  bool   `json:"enable_rpc"`
		registry   registry.Registry
		Server     Server
		Context    context.Context
	}
	
	Option func(o *Options)
)

func WithName(name string, version string) Option {
	return func(o *Options) {
		o.Name = name
		o.Version = version
	}
}

func WithRegistry(r registry.Registry) Option {
	return func(o *Options) {
		o.registry = r
	}
}

func WithServer(s Server) Option {
	return func(o *Options) {
		o.Server = s
	}
}

func WithoutHttp() Option {
	return func(o *Options) {
		o.EnableHttp = false
	}
}

func WithoutRPC() Option {
	return func(o *Options) {
		o.EnableRPC = false
	}
}

func NewOptions() *Options {
	return &Options{
		Zone:       "default",
		Version:    "1.0.1",
		EnableHttp: true,
		EnableRPC:  true,
		Context:    context.Background(),
		registry:   registry.DefaultRegistry,
	}
}
